'use strict';

var _electron = require('electron');

var _electron2 = _interopRequireDefault(_electron);

var _chokidar = require('chokidar');

var _chokidar2 = _interopRequireDefault(_chokidar);

var _electronJsonStorage = require('electron-json-storage');

var _electronJsonStorage2 = _interopRequireDefault(_electronJsonStorage);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _postManager = require('./post-manager.js');

var _postManager2 = _interopRequireDefault(_postManager);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var app = _electron2.default.app;
var Menu = _electron2.default.Menu;
var Tray = _electron2.default.Tray;
var shell = _electron2.default.shell;
var dialog = _electron2.default.dialog;
var ipcMain = _electron2.default.ipcMain;

var STATUS_FILE = _path2.default.join(app.getPath('userData'), './status.json');

var _post = new _postManager2.default();
var _watcher = null;

app.on('ready', function () {
  var status = void 0;
  try {
    var content = _fs2.default.readFileSync(STATUS_FILE, 'utf8');
    status = content ? JSON.parse(content) : {};
  } catch (e) {
    status = {};
  }

  _post.start(status);

  if (process.platform === 'darwin') {
    _createMenu();
  } else {
    _createTrayMenu();
  }

  _watcher = _chokidar2.default.watch(_post.folder, { ignoreInitial: true });
  _watcher.on('add', _post.open.bind(_post));
});

app.on('before-quit', function (event) {
  var status = _post.stop();
  _fs2.default.writeFileSync(STATUS_FILE, JSON.stringify(status, null, '  '));
});

app.on('window-all-closed', function () {});

ipcMain.on('add-post', function () {
  return _post.add();
});

function _createMenu() {
  var menuTemplate = [{
    label: app.getName(),
    submenu: [{ label: '付箋フォルダ指定...', click: function click() {
        var options = {
          title: '付箋フォルダを選択してください。',
          properties: ['openDirectory']
        };
        var directories = dialog.showOpenDialog(options);
        if (directories && directories[0]) {
          _watcher.close();

          _post.changeFolder(directories[0]);
          _watcher = _chokidar2.default.watch(_post.folder, { ignoreInitial: true });
          _watcher.on('add', _post.open.bind(_post));
        }
      } }, { label: '付箋フォルダを開く', click: function click() {
        shell.openItem(_post.folder);
      } }, { label: '終了', accelerator: 'Cmd+Q', click: app.quit }]
  }, {
    label: 'ファイル',
    submenu: [{ label: '新しい付箋', accelerator: 'Cmd+N', click: _post.add.bind(_post) }]
  }, {
    label: "編集",
    submenu: [{
      label: "コピー",
      accelerator: "CmdOrCtrl+C",
      role: "copy"
    }, {
      label: "ペースト",
      accelerator: "CmdOrCtrl+V",
      role: "paste"
    }, {
      label: "カット",
      accelerator: "CmdOrCtrl+X",
      role: "cut"
    }, {
      label: "すべて選択",
      accelerator: "CmdOrCtrl+A",
      role: "selectall"
    }]
  }];

  var menu = Menu.buildFromTemplate(menuTemplate);
  Menu.setApplicationMenu(menu);
}

function _createTrayMenu() {
  var menuTemplate = [{ label: '新しい付箋', click: _post.add.bind(_post) }, { label: '付箋フォルダ指定...', click: function click() {
      var options = {
        title: '付箋フォルダを選択してください。',
        properties: ['openDirectory']
      };
      var directories = dialog.showOpenDialog(options);
      if (directories && directories[0]) {
        _watcher.close();

        _post.changeFolder(directories[0]);
        _watcher = _chokidar2.default.watch(_post.folder, { ignoreInitial: true });
        _watcher.on('add', _post.open.bind(_post));
      }
    } }, { label: '付箋フォルダを開く', click: function click() {
      shell.openItem(_post.folder);
    } }, { label: '終了', click: app.quit }];

  var menu = Menu.buildFromTemplate(menuTemplate);
  var trayIcon = new Tray(__dirname + '/../icons/tag-32.png');
  trayIcon.setContextMenu(menu);
  trayIcon.setToolTip(app.getName());
}
//# sourceMappingURL=app.js.map
