'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _electron = require('electron');

var _electron2 = _interopRequireDefault(_electron);

var _sprintfJs = require('sprintf-js');

var _sprintfJs2 = _interopRequireDefault(_sprintfJs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _electronLocalshortcut = require('electron-localshortcut');

var _electronLocalshortcut2 = _interopRequireDefault(_electronLocalshortcut);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var BrowserWindow = _electron2.default.BrowserWindow;
var sprintf = _sprintfJs2.default.sprintf;

var PostsFolder = _path2.default.resolve(_path2.default.join(__dirname, '../posts'));
var DEFAULT_FOLDER = PostsFolder;

var _windows = [];

var _Instance = function _Instance() {
  _classCallCheck(this, _Instance);

  this.path = '';
  this.bounds = {};
  this.autoResize = false;
};

var PostManager = function () {
  function PostManager() {
    _classCallCheck(this, PostManager);

    this.folder = '';
  }

  _createClass(PostManager, [{
    key: 'start',
    value: function start(status) {
      var all = {};
      for (var file in status.posts) {
        all[file] = Object.assign(new _Instance(), status.posts[file]);
      }

      this.folder = status.folder ? status.folder : DEFAULT_FOLDER;
      this.all = all;

      _openAll(this);

      for (var _file in this.all) {
        if (_file in _windows) {
          delete this.all[_file];
        }
      }
    }
  }, {
    key: 'changeFolder',
    value: function changeFolder(path) {
      _closeAll(this);

      this.folder = path;
      this.all = [];

      _openAll(this);
    }
  }, {
    key: 'stop',
    value: function stop() {
      var posts = {};
      for (var file in this.all) {
        posts[file] = {
          autoResize: this.all[file].autoResize,
          bounds: this.all[file].bounds
        };
      }

      return { folder: this.folder, posts: posts };
    }
  }, {
    key: 'open',
    value: function open(fullPath) {
      var width = 200,
          height = 200;
      var file = _path2.default.basename(fullPath);
      var instance = this.all[file];
      var bounds = void 0;

      if (instance && instance.bounds) {
        bounds = instance.bounds;
        width = bounds.width;
        height = bounds.height;
      } else {
        instance = new _Instance();
        this.all[file] = instance;
      }

      var options = {
        width: width, height: height, frame: false, show: false,
        fullscreen: false, minimizable: true, maximizable: false,
        webPreferences: { webSecurity: false }
      };

      if (bounds) {
        Object.assign(options, { x: bounds.x, y: bounds.y });
      }

      var window = new BrowserWindow(options);

      _windows.push(window);

      instance.path = fullPath;

      window.instance = instance;
      window.loadURL('file://' + __dirname + '/renderer/post.html');
      window.setMenu(null);

      var updateBounds = function updateBounds() {
        Object.assign(window.instance.bounds, window.getBounds());
      };
      window.on('resize', updateBounds);
      window.on('move', updateBounds);

      _electronLocalshortcut2.default.register(window, 'CommandOrControl+Shift+I', function () {
        window.openDevTools();
      });

      // BrouserWindowインスタンスへの参照を破棄しているだけ。
      // アプリ終了後に参照残りに関連するっぽいエラーが出るが、原因不明。
      // 破棄に関してはこれだけやれば十分なはずだが…
      window.on('closed', function () {
        for (var i = 0; i < _windows.length; i++) {
          if (_windows[i] === window) {
            _windows[i] = null;
            delete _windows[i];
          }
        }
        _windows = _windows.filter(function (win) {
          return win !== null;
        });
      });
    }
  }, {
    key: 'add',
    value: function add() {
      var fullPath = _getNewFullPath(this.folder);
      _fs2.default.writeFileSync(fullPath, "");
    }
  }]);

  return PostManager;
}();

exports.default = PostManager;


function _openAll(post) {
  var files = _fs2.default.readdirSync(post.folder);
  if (!files) {
    throw new Error();
  }

  var fullpath = function fullpath(file) {
    return post.folder + '/' + file;
  };
  files.filter(function (file) {
    return _fs2.default.statSync(fullpath(file)).isFile();
  }).forEach(function (file) {
    post.open(fullpath(file));
  });
}

function _closeAll(post) {
  while (_windows.length > 0) {
    _windows[0].close();
  }
}

function _getNewFullPath(folder) {
  var files = _fs2.default.readdirSync(folder);
  if (!files) {
    throw new Error();
  }

  var candidate = void 0,
      result = null;
  for (var i = 0; i < 100; i++) {
    candidate = sprintf('post_%03d.txt', i);

    if (!files.includes(candidate)) {
      result = folder + '/' + candidate;
      break;
    }
  }

  if (!result) {
    throw new Error();
  }

  return result;
}
//# sourceMappingURL=post-manager.js.map
